@@ -101,15 +101,8 @@ void terminal_util_bind_object_property_to_widget (GObject *object,
         GtkWidget *widget,
         PropertyChangeFlags flags);
 
-gboolean terminal_util_x11_get_net_wm_desktop (GdkWindow *window,
-        guint32   *desktop);
-void     terminal_util_x11_set_net_wm_desktop (GdkWindow *window,
-        guint32    desktop);
-
 void terminal_util_x11_clear_demands_attention (GdkWindow *window);
 
-gboolean terminal_util_x11_window_is_minimized (GdkWindow *window);
-
 G_END_DECLS
 
 #endif /* TERMINAL_UTIL_H */
